@@ -40,7 +40,7 @@ class Completions(object):
         payload = {
             "id": chat_id,
             "chat_id": chat_id,
-            "model": "0727-360B-API",
+            "model": "0727-360B-API", # GLM-4-6-API-V1
 
             "stream": True,
 
