@@ -29,8 +29,10 @@ from meutils.apis.jimeng.images import generate as jimeng_generate
 from meutils.apis.qwen.chat import Completions as QwenCompletions
 from meutils.apis.google.chat import Completions as GoogleCompletions
 from meutils.apis.google.images import openai_generate
-
-from meutils.apis.volcengine_apis.videos import get_valid_token as get_valid_token_for_volc
+from meutils.apis.ppio.images import generate as ppio_generate
+from meutils.apis.runware.images import generate as runware_generate
+from meutils.apis.vmodel.images import generate as vmodel_generate
+from meutils.apis.freepik.images import generate as freepik_generate
 
 
 async def generate(
@@ -41,6 +43,12 @@ async def generate(
     if len(str(request)) < 1024:
         logger.debug(request)
 
+    if api_key and api_key.startswith("FPS"):  # freepik
+        return await freepik_generate(request, api_key)
+
+    if len(request.model) == 64 and request.model.islower():  # 粗糙
+        return await vmodel_generate(request, api_key)
+
     if request.model.startswith("fal-ai"):  # 国外fal
         request.image = await to_url_fal(request.image, content_type="image/png")
         response = await fal_generate(request, api_key)
@@ -70,7 +78,7 @@ async def generate(
 
             response.data = [{"url": url} for url in urls] + response.data
 
-        send_message_for_images(response.data)
+        send_message_for_images(response.data, title=__file__)
 
         return response
 
@@ -78,10 +86,11 @@ async def generate(
         request = RecraftImageRequest(**request.model_dump(exclude_none=True))
         return await recraft_generate(request)
 
-    if request.model.startswith(("jimeng", "seed", "seededit_v3.0", "byteedit_v2.0", "i2i_portrait_photo")):  # seededit seedream
+    if request.model.startswith(
+            ("jimeng", "seed", "seededit_v3.0", "byteedit_v2.0", "i2i_portrait_photo")):  # seededit seedream
         return await volc_generate(request, api_key)
 
-    if request.model.startswith(("jimeng")):  # 即梦
+    if request.model.startswith(("jimeng")):  # 即梦 逆向
         return await jimeng_generate(request)
 
     if request.model in {"Hunyuan3D-2", "Hi3DGen", "Step1X-3D"}:
@@ -94,12 +103,21 @@ async def generate(
         return await QwenCompletions(api_key=api_key).generate(request)
 
     if request.model.startswith(("google/gemini", "gemini")):  # openrouter
-        if api_key.endswith("-openai"):
+        if "ppi" in base_url:
+            if request.size == "auto":  # 不兼容
+                request.size = "1024x1024"
+
+            return await ppio_generate(request, api_key, base_url)
+
+        elif api_key.endswith("-openai"):
             api_key = api_key.removesuffix("-openai")
             return await openai_generate(request, base_url=base_url, api_key=api_key)
         else:
             return await GoogleCompletions(base_url=base_url, api_key=api_key).generate(request)  # 原生接口
 
+    if request.model.startswith("runware") or all(i in request.model for i in {":", "@"}):
+        return await runware_generate(request, api_key)
+
     # 其他
     data = {
         **request.model_dump(exclude_none=True, exclude={"extra_fields", "aspect_ratio"}),
@@ -108,7 +126,6 @@ async def generate(
     request = ImageRequest(**data)
     if request.model.startswith("doubao"):
         base_url = base_url or os.getenv("VOLC_BASE_URL")
-        api_key = api_key or await get_valid_token_for_volc()
         api_key = api_key.split()[0]  # 一个号并发足够
 
         request.stream = False
@@ -132,13 +149,26 @@ async def generate(
         elif request.image and isinstance(request.image, list):
             request.image = request.image[0]
 
+        if "ppi" in base_url:  # 派欧 https://ppio.com/docs/models/reference-seedream4.0 images => image
+            request.images = request.image
+
+            data = to_openai_params(request)
+
+            client = AsyncClient(api_key=api_key, base_url=base_url)
+            response = await client.images.generate(**data)
+            if images := response.model_dump(exclude_none=True).get("images"):
+                response.data = [{"url": image} for image in images]
+                return response
+            raise Exception(f"生成图片失败: {response} \n\n{request}")
+
     data = to_openai_params(request)
 
     if len(str(data)) < 1024:
         logger.debug(bjson(data))
 
     client = AsyncClient(api_key=api_key, base_url=base_url)
-    return await client.images.generate(**data)
+    response = await client.images.generate(**data)
+    return response
 
 
 # "flux.1-krea-dev"
@@ -152,15 +182,21 @@ if __name__ == '__main__':
 
     request = ImageRequest(model="doubao-seedream-4-0-250828", prompt="a dog", size="1K")
 
-    # request = ImageRequest(
-    #     model="doubao-seedream-4-0-250828",
-    #     prompt="将小鸭子放在t恤上,生成1:2比例图",
-    #     size="4k",
-    #     image=[
-    #         "https://v3.fal.media/files/penguin/XoW0qavfF-ahg-jX4BMyL_image.webp",
-    #         "https://v3.fal.media/files/tiger/bml6YA7DWJXOigadvxk75_image.webp"
-    #     ]
-    # )
+    request = ImageRequest(
+        model="doubao-seedream-4-0-250828",
+        prompt="将小鸭子放在t恤上,生成1:2比例图",
+        size="1k",
+        # image=[
+        #     "https://v3.fal.media/files/penguin/XoW0qavfF-ahg-jX4BMyL_image.webp",
+        #     "https://v3.fal.media/files/tiger/bml6YA7DWJXOigadvxk75_image.webp"
+        # ]
+    )
+
+    request = ImageRequest(
+        **{"model": "doubao-seedream-4-0-250828", "prompt": "a cat", "n": 2, "size": "1024x1024",
+           "response_format": "url"}
+
+    )
 
     # todo: tokens 4096 1张
 
@@ -176,4 +212,19 @@ if __name__ == '__main__':
 
     # print(not any(i in str(request.image) for i in {".png", ".jpeg", "image/png", "image/jpeg"}))
 
-    arun(generate(request))  # +"-29494"
+    api_key = "sk_fRr6ieXTMfym7Q6cnbj0YBlB1QsE74G8ygqIE2AyGz0"
+    base_url = "http://all.chatfire.cn/ppinfra/v1"
+
+    # arun(generate(request, api_key=api_key, base_url=base_url))
+
+
+    api_key = "FPSXc7a13cdcd4893ff3aa053749d05485a7"
+    model = "gemini-2-5-flash-image-preview"
+
+    request = ImageRequest(
+        model=model,
+        prompt="带个墨镜",
+        image=["https://s3.ffire.cc/files/jimeng.jpg"],
+    )
+
+    arun(generate(request, api_key=api_key, base_url=base_url))
