@@ -7,9 +7,7 @@
 # @WeChat       : meutils
 # @Software     : PyCharm
 # @Description  :
-import os
-
-import httpx
+# todo {"code":"upstream_error","message":"","data":null,"status_code":406,"error":{}}
 
 from meutils.pipe import *
 from openai import AsyncClient
