@@ -14,7 +14,7 @@ https://www.volcengine.com/docs/6791/1384311
 """
 
 from meutils.pipe import *
-from meutils.decorators.retry import retrying
+from meutils.decorators.retry import retrying, IgnoredRetryException
 
 from meutils.io.files_utils import to_url
 from meutils.schemas.image_types import ImageRequest, ImagesResponse
@@ -22,6 +22,7 @@ from meutils.schemas.image_types import ImageRequest, ImagesResponse
 from volcengine.visual.VisualService import VisualService
 
 
+@retrying(max_retries=5, ignored_exception_types=IgnoredRetryException)
 async def generate(request: ImageRequest, token: Optional[str] = None):
     """
 
@@ -51,13 +52,21 @@ async def generate(request: ImageRequest, token: Optional[str] = None):
         # "use_rephraser": True
     }
 
-    if request.model == "jimeng_t2i_v31":
+    if request.model == "jimeng_t2i_v31":  # jimeng_t2i_v40
         payload["req_key"] = request.model  # 模型名称 重定向
 
+    elif request.model == "jimeng_t2i_v40":
+        payload["req_key"] = request.model
+        if request.n > 1:
+            request.prompt = f"{request.prompt} \n\n 生成一组 {request.n} 张图片"
+
+        else:
+            payload['force_single'] = True
+
     if request.image_urls:
         payload["image_urls"] = request.image_urls
 
-        if payload["req_key"] not in {"seededit_v3.0", "byteedit_v2.0"}:
+        if payload["req_key"] not in {"seededit_v3.0", "byteedit_v2.0", "jimeng_t2i_v40"}:
             payload["req_key"] = "byteedit_v2.0"  # "seededit_v3.0" https://www.volcengine.com/docs/85128/1602254
 
     width, height = map(int, request.size.split('x'))
@@ -74,6 +83,9 @@ async def generate(request: ImageRequest, token: Optional[str] = None):
         logger.debug(bjson(response))
     except Exception as exc:  #
         logger.error(exc)
+        if "Text Risk Not Pass" in str(exc):
+            raise IgnoredRetryException(exc)
+
         raise exc
 
     if request.response_format == "b64_json":
@@ -109,7 +121,9 @@ if __name__ == '__main__':
     request = ImageRequest(
         # model="high_aes_general_v30l_zt2i",
         # model="seededit_v3.0",
-        model="jimeng_t2i_v31",
+        # model="jimeng_t2i_v31",
+
+        model="jimeng_t2i_v40",
         prompt=prompt,
         response_format="url",
         seed=-1,
