@@ -15,12 +15,12 @@ models_mapping = {
     "glm-4.5": "zai-org/GLM-4.5",
     "glm-4.5v": "zai-org/GLM-4.5V",
 
-    "deepseek-v3": "deepseek-ai/DeepSeek-V3",
-    "deepseek-v3-0324": "deepseek-ai/DeepSeek-V3",
-    "deepseek-v3-250324": "deepseek-ai/DeepSeek-V3",
-    "deepseek-chat": "deepseek-ai/DeepSeek-V3",
-    "deepseek-v3.1": "deepseek-ai/DeepSeek-V3.1",
-    "deepseek-v3-1-250821": "deepseek-ai/DeepSeek-V3.1",
+    "deepseek-v3": "deepseek-ai/DeepSeek-V3.2-Exp",
+    "deepseek-v3-0324": "deepseek-ai/DeepSeek-V3.2-Exp",
+    "deepseek-v3-250324": "deepseek-ai/DeepSeek-V3.2-Exp",
+    "deepseek-chat": "deepseek-ai/DeepSeek-V3.2-Exp",
+    "deepseek-v3.1": "deepseek-ai/DeepSeek-V3.2-Exp",
+    "deepseek-v3-1-250821": "deepseek-ai/DeepSeek-V3.2-Exp",
 
     "qwen3-32b": "Qwen/Qwen3-32B",
     "deepseek-r1": "deepseek-ai/DeepSeek-R1",
@@ -57,7 +57,7 @@ models_mapping = {
 }
 
 
-def get_models_mapping():
+def get_models_mapping(startswith: str=""):
     client = OpenAI(
         api_key=os.getenv("SILICONFLOW_API_KEY"),
         base_url=os.getenv("SILICONFLOW_BASE_URL"),
@@ -66,12 +66,19 @@ def get_models_mapping():
     models = client.models.list().data
     models = {
         m.id.removeprefix("Pro/").split('/', maxsplit=1)[-1].lower(): m.id.removeprefix("Pro/") for m in models
-        if any(i not in m.id.lower() for i in {"stable-diffusion"})
+        if any(i not in m.id.lower() for i in {"stable-diffusion", "wan"})
     }
+    if startswith:
+        models = {k: v for k, v in models.items() if k.startswith(startswith)}
+        return models
+
     return {**models, **models_mapping}
 
 
 if __name__ == '__main__':
-    data = get_models_mapping()
+    startswith = ""
+    startswith = "ling"
+
+    data = get_models_mapping(startswith)
     print(bjson(data))
     print(','.join(data))
