@@ -69,16 +69,19 @@ async def chat_for_image(
         logger.debug(image_request)
 
     # 非流式
-    if not request.stream or request.last_user_content.startswith(  # 跳过nextchat
-            (
-                    "hi",
-                    "使用四到五个字直接返回这句话的简要主题",
-                    "简要总结一下对话内容，用作后续的上下文提示 prompt，控制在 200 字以内"
-            )):
-        # chat_completion.choices[0].message.content = "请设置`stream=True`"
-        # return chat_completion
+    if not request.stream:
+        if request.last_user_content.startswith(  # 跳过nextchat
+                (
+                        "hi",
+                        "使用四到五个字直接返回这句话的简要主题",
+                        "简要总结一下对话内容，用作后续的上下文提示 prompt，控制在 200 字以内"
+                )):
+            return chat_completion
 
-        response = await generate(image_request)
+        response = await generate(image_request)  # None
+
+        if not response:
+            raise Exception(f"image generate error: {str(request)[:1000]}")
 
         if not isinstance(response, dict):
             response = response.model_dump()
