@@ -25,6 +25,7 @@ from meutils.apis.oneapi.user import get_user_money
 from fastapi import status, HTTPException
 
 base_url = "https://api.chatfire.cn/flux/v1"
+# base_url = "http://110.42.51.201:38886/flux/v1"
 
 
 # base_url="http://110.42.51.201:38888/flux/v1"
@@ -46,6 +47,9 @@ async def billing_for_async_task(
                 path=f"/{model}",
                 payload={
                     "id": task_id,
+                    "seed": task_id,
+                    "webhook_secret": task_id,  # 平替 task_id
+                    # "prompt": "ChatfireAPI",
                     # 'polling_url': f'{base_url}/get_result?id={task_id}',
                 }
             )
@@ -176,6 +180,8 @@ def get_billing_model(
         request = request.model_dump()
 
     model = (request.get("model") or request.get("model_name") or default_model or "undefined model").lower()
+    if model.startswith("doubao-seedance"):
+        model = model.rsplit('-', maxsplit=1)[0].strip("-i2v").strip("-t2v")
 
     # 某些模型不需要匹配，单模型计费
     if model.startswith(("veo", "jimeng", "cogvideo")):  # todo 后续再拓展
@@ -264,7 +270,12 @@ if __name__ == '__main__':
 
     # arun(billing_for_async_task(model, task_id=task_id, n=3))
     # arun(billing_for_async_task(task_id='fal-ai-sync'))
-    arun(billing_for_async_task())
+    # model = "doubao-seedance-1-0-lite-i2v-250428_5s_10"
+    # model="doubao-seedance-1-0-lite-i2v-250428"
+    # model = "doubao-seedance-1-0-pro-250528_10s_1080p"
+    model = "minimax-hailuo-02_6s_1080p"
+    # model = "flux-kontext-pro"
+    arun(billing_for_async_task(model, task_id=model))
 
     data = {
         "video_url": "https://storage.googleapis.com/falserverless/example_inputs/wan_animate_input_video.mp4",
@@ -277,18 +288,87 @@ if __name__ == '__main__':
         "video_write_mode": "balanced"
     }
 
-    # data = {
-    #     "model": "doubao-seedance-1-0-pro-250528",
-    #     "content": [
-    #         {
-    #             "type": "text",
-    #             "text": "多个镜头。一名侦探进入一间光线昏暗的房间。他检查桌上的线索，手里拿起桌上的某个物品。镜头转向他正在思索。 --ratio 16:9"
-    #         }
-    #     ]
-    # }
-    #
-    print(get_billing_n(data))
+    data = {
+        "model": "doubao-seedance-1-0-pro-250528",
+        "content": [
+            {
+                "type": "text",
+                "text": "--resolution 1080p  --duration 10  --camerafixed true多个镜头。一名侦探进入一间光线昏暗的房间。他检查桌上的线索，手里拿起桌上的某个物品。镜头转向他正在思索。 --ratio 16:9，主体:男人转动头部打量四周\n景别:全景\n运镜:转动镜头\n视角:平视\n构图:居中构图\n风格统一:动漫风格"
+            }
+        ]
+    }
 
+    data = {
+        "model": "doubao-seedance-1-0-lite-i2v-250428",
+        "content": [
+            {
+                "text": "一本古老的魔法书，镜头弧形环绕至的正面俯视特写 --dur 10 --resolution 720p",
+                "type": "text"
+            },
+            {
+                "type": "image_url",
+                "image_url": {
+                    "url": "https://mjimg.zhanjuzhe.cn/raw/media/202510/28/20251028134055523409.png"
+                }
+            }
+        ]
+        ,
+        "duration": 5,
+        "created_at": 1761630940,
+        "resolution": "720p",
+        "updated_at": 1761630982,
+        "framespersecond": 24
+    }
+
+    data = {
+        "model": "doubao-seedance-1-0-pro-250528",
+        "content": [
+            {
+                "text": "推镜到女人脸，女人表情气鼓鼓的，微微皱眉，看着男人，右手摸着脑袋 ，然后放下手  --resolution 1080p  --duration 5  --camerafixed false",
+                "type": "text"
+            },
+            {
+                "type": "image_url",
+                "image_url": {
+                    "url": "https://cdn.jeff1992.com/ai-video/2025/10/28/mpyzyn_1761629867192.jpg"
+                }
+            }
+        ]
+        ,
+        "duration": 5,
+        "created_at": 1761630465,
+        "resolution": "1080p",
+        "updated_at": 1761630529,
+        "framespersecond": 24
+    }
+
+    data = {
+        "model": "doubao-seedance-1-0-lite-i2v-250428",
+        "content": [
+            {
+                "text": "男人背过身，抬头看到红布条 --rs 1080p --dur 5 --cf false --seed -1 --wm false --rt 9:16",
+                "type": "text"
+            },
+            {
+                "role": "first_frame",
+                "type": "image_url",
+                "image_url": {
+                    "url": "https://renren-animation.xyzpgc.com/resources/png/2025/10/28/byteFile-1761620822538-4760.png"
+                }
+            }
+        ]
+        ,
+        "duration": 5,
+        "created_at": 1761633057,
+        "resolution": "1080p",
+        "updated_at": 1761633094,
+        "framespersecond": 24
+    }
+
+    #
+    print(get_billing_model(data))  # doubao-seedance-1-0-lite-i2v-250428_10s_720p
+
+    # doubao-seedance-1-0-pro-250528_5s_1080p
     #
     # arun(get_async_task(task_id))
     #
