@@ -6,8 +6,8 @@
 # @Author       : betterme
 # @WeChat       : meutils
 # @Software     : PyCharm
-# @Description  : 
-
+# @Description  :
+import httpx
 import oss2
 
 from meutils.pipe import *
@@ -15,6 +15,10 @@ from meutils.caches import rcache
 from meutils.io.files_utils import guess_mime_type
 from meutils.config_utils.lark_utils import get_next_token_for_polling
 
+from fake_useragent import UserAgent
+
+ua = UserAgent()
+
 FEISHU_URL = "https://xchatllm.feishu.cn/sheets/Bmjtst2f6hfMqFttbhLcdfRJnNf?sheet=PP1PGr"
 
 # params = {
@@ -29,7 +33,7 @@ FEISHU_URL = "https://xchatllm.feishu.cn/sheets/Bmjtst2f6hfMqFttbhLcdfRJnNf?shee
 # }
 
 
-url = "https://chat.qwen.ai/api/v1/files/getstsToken"
+url = "https://chat.qwen.ai/api/v2/files/getstsToken"
 
 
 async def get_sts_token(filename, filetype: Optional[str] = None, token: Optional[str] = None):
@@ -38,23 +42,31 @@ async def get_sts_token(filename, filetype: Optional[str] = None, token: Optiona
     filetype = filetype or guess_mime_type(filename).split('/')[0]
 
     payload = {
-        "filename": filename,
+        "filename": Path(filename).name,
         "filetype": filetype,  # file video audio
         "filesize": 1001
     }
 
+    # logger.debug(payload)
+
     headers = {
         'authorization': f'Bearer {token}',
+        'Content-Type': 'application/json',
+        'User-Agent': ua.random,
     }
 
-    response = requests.request("POST", url, headers=headers, json=payload)
+    async with httpx.AsyncClient(timeout=120) as client:
+        response = await client.post(url, headers=headers, json=payload)
+        response.raise_for_status()
 
-    return response.json()
+        return response.json()["data"]
 
 
 async def qwenai_upload(file, filetype: Optional[str] = None, token: Optional[str] = None):  # todo: 自动猜测类型
     params = await get_sts_token(file_name, filetype, token)
 
+    logger.debug(params)
+
     access_key_id = params['access_key_id']
     access_key_secret = params['access_key_secret']
     security_token = params['security_token']
@@ -70,20 +82,19 @@ async def qwenai_upload(file, filetype: Optional[str] = None, token: Optional[st
     file_path = params.get("file_path")
     file_url = params.get("file_url")
 
-    logger.debug(params)
-
     # 上传文件
     if isinstance(file, bytes):
         bucket.put_object(file_path, file)
     else:
         bucket.put_object_from_file(file_path, file)
 
-    return file_url
+    return file_url  # params
 
 
 if __name__ == '__main__':
     # qwenai_upload(params['file_path'], params)
     file_name = "/Users/betterme/PycharmProjects/AI/QR.png"
+    token = "eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJpZCI6IjMxMGNiZGFmLTM3NTQtNDYxYy1hM2ZmLTllYzgwMDUzMjljOSIsImxhc3RfcGFzc3dvcmRfY2hhbmdlIjoxNzUwNjYwODczLCJleHAiOjE3NTk0Nzk4NjR9.77bcjaW4R-fQrUyYB3YgOLW1qDcdsckYwhRxW0ZQBMI"
 
-    # arun(get_sts_token(file_name))
+    # arun(get_sts_token(file_name, token=token))
     file_url = arun(qwenai_upload(file_name))
