@@ -62,6 +62,8 @@ class Minio(_Minio):
             length=len(file),
         )
 
+        logger.debug(_)
+
         return f"https://{self.endpoint}/{bucket_name}/{object_name}"
 
     async def put_object_for_openai(
@@ -107,6 +109,8 @@ class Minio(_Minio):
 
                 filename=filename,
             )
+            logger.debug(file)
+
         file_name = filename or file.filename or shortuuid.random()
 
         content_type = (
