@@ -22,7 +22,7 @@ MJ_FAST = 1.5
 STEP = 2
 MINIMAX_VIDEO = 2 * 0.6
 
-FAL = 3
+FAL = 4
 FAL_ = 5
 FAL_MODELS = {
     #
@@ -38,19 +38,19 @@ FAL_MODELS = {
     'fal-pixverse-v4.5-image-to-video-fast': 1.8,
 
     # flux
-    'fal-flux-1-schnell': 0.003 * 4,
-    'fal-flux-1-schnell-redux': 0.025 * 4,
-    'fal-flux-1-dev': 0.025 * 3,
-    'fal-flux-1-dev-image-to-image': 0.03 * 3,
-    'fal-flux-1-dev-redux': 0.025 * 3,
+    'fal-flux-1-schnell': 0.003 * FAL,
+    'fal-flux-1-schnell-redux': 0.025 * FAL,
+    'fal-flux-1-dev': 0.025 * FAL,
+    'fal-flux-1-dev-image-to-image': 0.03 * FAL,
+    'fal-flux-1-dev-redux': 0.025 * FAL,
 
-    'fal-flux-pro-kontext': 0.04 * 3,
+    'fal-flux-pro-kontext': 0.04 * FAL,
     'fal-flux-pro-kontext-text-to-image': 0.1,
-    'fal-flux-pro-kontext-multi': 0.04 * 3,
+    'fal-flux-pro-kontext-multi': 0.04 * FAL,
 
-    'fal-flux-pro-kontext-max': 0.08 * 3,
-    'fal-flux-pro-kontext-max-text-to-image': 0.08 * 3,
-    'fal-flux-pro-kontext-max-multi': 0.08 * 3,
+    'fal-flux-pro-kontext-max': 0.08 * FAL,
+    'fal-flux-pro-kontext-max-text-to-image': 0.08 * FAL,
+    'fal-flux-pro-kontext-max-multi': 0.08 * FAL,
 
     # minimax hailuo
     "fal-ai/minimax/hailuo-02/standard/text-to-video": 0.27 * FAL,  # 6 10
@@ -78,7 +78,7 @@ FAL_MODELS = {
     "fal-ai/ideogram/v3/replace-background": 0.06 * FAL_,
 
     # recraft
-    "fal-ai/recraft/upscale/crisp": 0.004 * FAL_,
+    "fal-ai/recraft/upscale/crisp": 0.025,
     "fal-ai/recraft/upscale/creative": 0.25 * FAL_,
     "fal-ai/recraft/v3/image-to-image": 0.06 * FAL_,  # 0.04 0.08 vec
     "fal-ai/recraft/v3/text-to-image": 0.06 * FAL_,
@@ -139,8 +139,9 @@ REPLICATE_MODELS = {
     'black-forest-labs/flux-canny-pro': 0.05 * FAL,
     'black-forest-labs/flux-depth-pro': 0.05 * FAL,
 
-    'black-forest-labs/flux-kontext-max': 0.04 * FAL,
-    'black-forest-labs/flux-kontext-pro': 0.08 * FAL,
+    'black-forest-labs/flux-kontext-pro': 0.04 * FAL,
+    'black-forest-labs/flux-kontext-max': 0.08 * 3.5,
+
 }
 
 MODEL_PRICE = {
@@ -148,8 +149,10 @@ MODEL_PRICE = {
     **REPLICATE_MODELS,
 
     "nano-banana": 0.04 * 3,
+    "nano-banana-pro": 0.04 * 4,
+
     "gemini-2.5-flash-image": 0.04 * 3,
-    "gemini-2.5-flash-image-preview": 0.03,
+    "gemini-2.5-flash-image-preview": 0.08,
     "gemini-2.5-flash-image-preview-hd": 0.08,
 
     "qwen-image": 0.05,
@@ -225,20 +228,40 @@ MODEL_PRICE = {
     "doubao-seededit-3-0-i2i-250628": 0.05,
     "jimeng_t2i_v31": 0.05,
 
-    "doubao-seedance-1-0-pro": 0.5,  # 480 1080
-    "doubao-seedance-1-0-pro-250528": 0.5,  # 480 1080
+    "jimeng-3.0": 0.05,
+    "jimeng-3.1": 0.05,
+    "jimeng-4.0": 0.05,
 
-    "doubao-seedance-1-0-lite-t2v-250428": 0.4,
     "doubao-seedance-1-0-lite-i2v-250428": 0.4,
+    "doubao-seedance-1-0-lite-t2v-250428": 0.4,
+    "doubao-seedance-1-0-pro-250528": 0.5,
+    "doubao-seedance-1-0-pro-fast-251015": 0.3,
+
+    "doubao-seedance-1-0-lite_5s_480p": 0.4,
+    "doubao-seedance-1-0-lite_10s_480p": 0.8,
+    "doubao-seedance-1-0-lite_5s_720p": 0.8,
+    "doubao-seedance-1-0-lite_10s_720p": 1.2,
+    "doubao-seedance-1-0-lite_5s_1080p": 0.7 * 2.5,
+    "doubao-seedance-1-0-lite_10s_1080p": 0.7 * 2.5 * 2,
+
+    "doubao-seedance-1-0-pro_5s_480p": 0.5,
+    "doubao-seedance-1-0-pro_10s_480p": 1,
+    "doubao-seedance-1-0-pro_5s_720p": 1,
+    "doubao-seedance-1-0-pro_10s_720p": 2,
+    "doubao-seedance-1-0-pro_5s_1080p": 2.5,
+    "doubao-seedance-1-0-pro_10s_1080p": 5,
 
     "api-volcengine-high_aes_general_v30l_zt2i": 0.05,
     "api-volcengine-byteedit_v2.0": 0.05,
 
     # veo
-    "veo3": 2,
-    "veo3-frames": 2,
-    "veo3-pro": 8,
-    "veo3-pro-frames": 8,
+    "veo3": 1,
+    "veo3-frames": 1,
+    "veo3-pro": 4,
+    "veo3-pro-frames": 4,
+
+    "veo3.1": 1,
+    "veo3.1-pro": 4,
 
     # hailuo https://www.minimax.io/price
     "minimax-hailuo-02": 1,
@@ -272,6 +295,7 @@ MODEL_PRICE = {
     "dall-e-3": 0.03,
     "sora-2": 0.2,
     "sora-2-hd": 0.2,
+    "sora-2-pro": 2,
 
     # rag
     "qwen3-reranker-0.6b": 0.0011,
@@ -332,7 +356,6 @@ MODEL_PRICE = {
     "recraft-api": 0.1,
     "chat-recraftv3": 0.1,
 
-    "flux-pro-1.1-ultra": 0.2,
     "ideogram-ai/ideogram-v2": 0.2,
     "ideogram-ai/ideogram-v2-turbo": 0.1,
     "ideogram-v3": 0.06 * 3,
@@ -347,6 +370,9 @@ MODEL_PRICE = {
     "flux-kontext-pro": 0.04 * 3,
     "flux-kontext-max": 0.08 * 3,
 
+    "flux-pro-1.1-ultra": 0.06 * FAL,
+    "flux-1.1-pro-ultra": 0.06 * FAL,
+
     "api-asr": 0.01,
     "api-stt": 0.01,
     "api-tts": 0.01,
@@ -356,7 +382,7 @@ MODEL_PRICE = {
 
     "api-hunyuan-video": 0.1,
 
-    "deepseek-ai/Janus-Pro-7B": 0.01,
+    "deepseek-ocr": 0.01,
 
     # sd
     "stable-diffusion-xl-base-1.0": 0.01,
@@ -448,13 +474,13 @@ MODEL_PRICE = {
     "api-textin-crop_enhance_image": 0.03,
 
     # suno
-    "suno_music": 0.45,
+    "suno_music": 0.6,
     "suno_lyrics": 0.01,
     "suno_uploads": 0.01,
     "suno_upload": 0.01,
     "suno_concat": 0.01,
     "chirp-v3-5": 0.5,
-    "chat-suno": 0.5,
+    "chat-suno": 0.6,
 
     # all
     "o1-plus": 0.2,
@@ -663,6 +689,8 @@ MODEL_RATIO = {
 
     "seed-oss-36b-instruct": 0.75,
     "ling-mini-2.0": 0.25,
+    "ling-flash-2.0": 0.5,
+    "ling-1t": 2,
 
     # 百川
     'baichuan4-turbo': 7.5,
@@ -772,6 +800,8 @@ MODEL_RATIO = {
     "qwen-max-2025-01-25": 1.2 * 1,
     "qwen3-max": 3,
     "qwen3-max-preview": 3,
+    "qwen3-max-2025-10-30": 3,
+    "qwen3-max-2025-10-30-thinking": 3,
     "qwen3-next-80b-a3b": 0.5,
     "qwen3-next-80b-a3b-instruct": 0.5,
     "qwen3-next-80b-a3b-thinking": 0.5,
@@ -811,6 +841,10 @@ MODEL_RATIO = {
     "qwen3-vl-235b-a22b": 0.5,
     "qwen3-vl-235b-a22b-instruct": 1,
     "qwen3-vl-235b-a22b-thinking": 1,
+    "qwen3-vl-30b-a3b-instruct": 0.5,
+    "qwen3-vl-30b-a3b-thinking": 0.5,
+    "qwen3-vl-8b-thinking": 0.1,
+    "qwen3-vl-8b-instruct": 0.1,
 
     "qwen3-coder-plus": 2,
     "qwen3-coder-plus-2025-07-22": 2,
@@ -882,6 +916,7 @@ MODEL_RATIO = {
     # minimax https://platform.minimaxi.com/document/price?id=6433f32294878d408fc8293e
     "minimax-text-01": 0.5,
     "minimax-m1-80k": 2,
+    "minimax-m2": 1,
 
     "abab6.5-chat": 15 / 7.5,
     "abab6.5s-chat": 5,
@@ -962,9 +997,10 @@ MODEL_RATIO = {
     "doubao-seed-1-6-flash-250715": 0.15,
     "doubao-seed-1-6-flash-250615": 0.15,
     "doubao-seed-1-6-250615": 0.4,
+    "doubao-seed-1-6-251015": 0.4,
     "doubao-seed-1-6-thinking-250615": 0.4,
     "doubao-seed-1-6-thinking-250715": 0.4,
-    "doubao-seed-1-6-vision-250815": 0.6,
+    "doubao-seed-1-6-vision-250815": 0.4,
 
     "doubao-1-5-ui-tars-250428": 1.75,
     "ui-tars-72b": 1.75,
@@ -1070,6 +1106,8 @@ MODEL_RATIO = {
     # claude
 
     "claude-3-5-haiku-20241022": 0.5,
+    "claude-haiku-4-5-20251001": 0.5,
+
     "anthropic/claude-3-5-haiku-20241022:beta": 0.5,
 
     "claude-3-haiku-20240307": 0.125,
@@ -1319,6 +1357,7 @@ MODEL_RATIO = {
 COMPLETION_RATIO = {
     "minimax-text-01": 8,
     "minimax-m1-80k": 4,
+    "minimax-m2": 4,
 
     # 智能体
     "gpt-4-plus": 5,
@@ -1419,6 +1458,7 @@ COMPLETION_RATIO = {
 
     # claude
     "claude-3-5-haiku-20241022": 5,
+    "claude-haiku-4-5-20251001": 5,
     "anthropic/claude-3-5-haiku-20241022:beta": 5,
 
     "claude-3-opus-20240229": 5,
@@ -1552,6 +1592,8 @@ COMPLETION_RATIO = {
     "qwen-max": 4,
     "qwen3-max": 4,
     "qwen3-max-preview": 4,
+    "qwen3-max-2025-10-30": 10,
+    "qwen3-max-2025-10-30-thinking": 3,
     "qwen3-next-80b-a3b": 4,
     "qwen3-next-80b-a3b-instruct": 4,
     "qwen3-next-80b-a3b-thinking": 10,
@@ -1564,6 +1606,10 @@ COMPLETION_RATIO = {
     "qwen3-vl-235b-a22b": 10,
     "qwen3-vl-235b-a22b-instruct": 4,
     "qwen3-vl-235b-a22b-thinking": 10,
+    "qwen3-vl-30b-a3b-instruct": 4,
+    "qwen3-vl-30b-a3b-thinking": 10,
+    "qwen3-vl-8b-thinking": 4,
+    "qwen3-vl-8b-instruct": 10,
 
     "qwen2.5-vl-7b-instruct": 4,
     "qwen2.5-vl-32b-instruct": 4,
@@ -1622,9 +1668,11 @@ COMPLETION_RATIO = {
     "doubao-seed-1-6-flash-250615": 10,
     # doubao-seed-1-6-flash-250615,doubao-seed-1-6-250615,doubao-seed-1-6-thinking-250615
     "doubao-seed-1-6-250615": 10,
+    "doubao-seed-1-6-251015": 10,
+
     "doubao-seed-1-6-thinking-250615": 10,
     "doubao-seed-1-6-thinking-250715": 10,
-    "doubao-seed-1-6-vision-250815": 13.33,
+    "doubao-seed-1-6-vision-250815": 10,
 
     "doubao-1-5-ui-tars-250428": 3.43,
     "ui-tars-72b": 4,
@@ -1672,6 +1720,8 @@ COMPLETION_RATIO = {
 
     "seed-oss-36b-instruct": 4,
     "ling-mini-2.0": 4,
+    "ling-flash-2.0": 4,
+    "ling-1t": 4,
 
     "deepseek-prover-v2-671b": 4,
     "deepseek-r1:1.5b": 4,
@@ -1981,3 +2031,6 @@ if __name__ == '__main__':
 
     print('\n\n')
     print([k for k in MODEL_PRICE if k.startswith(('minimax-'))] | xjoin(","))
+
+    print('\n\n')
+    print([k for k in MODEL_PRICE if k.startswith(('doubao-seedance'))] | xjoin(","))
