@@ -133,7 +133,6 @@ class CompletionRequest(BaseModel):
 
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
-
     @cached_property
     def system_instruction(self):
         # [{'role': 'system', 'content':  [{"type": "text", "text": ""}]]
@@ -630,7 +629,9 @@ if __name__ == '__main__':
     # print(chat_completion_chunk_stop)
 
     # print(CompletionRequest(messages=messages).last_urls)
-    print(CompletionRequest(messages=messages).last_urls)
+    # print(CompletionRequest(messages=messages).last_urls)
+
+    r = CompletionRequest(messages=messages)
 
     # print(mesages)
     # print(CompletionRequest(messages=messages).last_assistant_content)
